pub struct StreamVerifier<'a> { /* private fields */ }Expand description
A StreamVerifier to verify a signature against a data stream
This mode of operation allows for verification of large files by processing them in chunks, without having to load the entire file into memory.
Note that this mode only works with pre-hashed signatures (not legacy mode).
Implementations